==> nifi-minifi-cpp-0.14.0-source.tar.gz: nifi-minifi-cpp-0.14.0-source/docker/test/integration/cluster/containers/AzureStorageServerContainer.py <==
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import logging
from .Container import Container


class AzureStorageServerContainer(Container):
    def __init__(self, name, vols, network, image_store, command=None):
        super().__init__(name, 'azure-storage-server', vols, network, image_store, command)

    def get_startup_finished_log_entry(self):
        return "Azurite Queue service is successfully listening at"

    def deploy(self):
        if not self.set_deployed():
            return

        logging.info('Creating and running azure storage server docker container...')
        self.client.containers.run(
            "mcr.microsoft.com/azure-storage/azurite:3.14.2",
            detach=True,
            name=self.name,
            network=self.network.name,
            ports={'10000/tcp': 10000, '10001/tcp': 10001},
            entrypoint=self.command)
        logging.info('Added container \'%s\'', self.name)

==> nifi-minifi-cpp-0.99.1-source.tar.gz: nifi-minifi-cpp-0.99.1-source/docker/test/integration/cluster/containers/AzureStorageServerContainer.py <==
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import logging
from .Container import Container


class AzureStorageServerContainer(Container):
    def __init__(self, feature_context, name, vols, network, image_store, command=None):
        super().__init__(feature_context, name, 'azure-storage-server', vols, network, image_store, command)

    def get_startup_finished_log_entry(self):
        return "Azurite Queue service is successfully listening at"

    def deploy(self):
        if not self.set_deployed():
            return

        logging.info('Creating and running azure storage server docker container...')
        self.client.containers.run(
            "mcr.microsoft.com/azure-storage/azurite:3.23.0",
            detach=True,
            name=self.name,
            network=self.network.name,
            ports={'10000/tcp': 10000, '10001/tcp': 10001},
            entrypoint=self.command)
        logging.info('Added container \'%s\'', self.name)
